package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcWlmqfzr;
import org.apache.ibatis.annotations.Param;

/**
 * 网络民情负责人Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcWlmqfzrMapper 
{
    /**
     * 查询网络民情负责人
     * 
     * @param id 网络民情负责人主键
     * @return 网络民情负责人
     */
    public TcWlmqfzr selectTcWlmqfzrById(Long id);

    /**
     * 查询网络民情负责人列表
     * 
     * @param tcWlmqfzr 网络民情负责人
     * @return 网络民情负责人集合
     */
    public List<TcWlmqfzr> selectTcWlmqfzrList(TcWlmqfzr tcWlmqfzr);

    /**
     * 新增网络民情负责人
     * 
     * @param tcWlmqfzr 网络民情负责人
     * @return 结果
     */
    public int insertTcWlmqfzr(TcWlmqfzr tcWlmqfzr);

    /**
     * 修改网络民情负责人
     * 
     * @param tcWlmqfzr 网络民情负责人
     * @return 结果
     */
    public int updateTcWlmqfzr(TcWlmqfzr tcWlmqfzr);

    /**
     * 删除网络民情负责人
     * 
     * @param id 网络民情负责人主键
     * @return 结果
     */
    public int deleteTcWlmqfzrById(Long id);

    /**
     * 批量删除网络民情负责人
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcWlmqfzrByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
