package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcWljgtj;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWlmqfzr;
import com.ruoyi.tcZz.service.ITcWlmqfzrService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 网络民情负责人Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@Api(tags = "网络民情负责人")
@RestController
@RequestMapping("/tcZz/networkEcology/wlmqfzr")
public class TcWlmqfzrController extends BaseController {
    @Autowired
    private ITcWlmqfzrService tcWlmqfzrService;

    /**
     * 查询网络民情负责人列表
     */
    @ApiOperation(value = "查询网络民情负责人列表", response = TcWlmqfzr.class)
    @GetMapping("/list")
    public TableDataInfo list(TcWlmqfzr tcWlmqfzr) {
        startPage();
        List<TcWlmqfzr> list = tcWlmqfzrService.selectTcWlmqfzrList(tcWlmqfzr);
        return getDataTable(list);
    }

    /**
     * 导出网络民情负责人列表
     */
    @ApiOperation(value = "导出网络民情负责人列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWlmqfzr tcWlmqfzr) {
        List<TcWlmqfzr> list = tcWlmqfzrService.selectTcWlmqfzrList(tcWlmqfzr);
        ExcelUtil<TcWlmqfzr> util = new ExcelUtil<TcWlmqfzr>(TcWlmqfzr.class);
        util.exportExcel(response, list, "网络民情负责人数据");
    }

    /**
     * 获取网络民情负责人详细信息
     */
    @ApiOperation(value = "获取网络民情负责人详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcWlmqfzrService.selectTcWlmqfzrById(id));
    }

    /**
     * 新增网络民情负责人
     */
    @ApiOperation(value = "新增网络民情负责人")
    @PostMapping
    public AjaxResult add(@RequestBody TcWlmqfzr tcWlmqfzr) {
        return toAjax(tcWlmqfzrService.insertTcWlmqfzr(tcWlmqfzr));
    }

    /**
     * 修改网络民情负责人
     */
    @ApiOperation(value = "修改网络民情负责人")
    @PutMapping
    public AjaxResult edit(@RequestBody TcWlmqfzr tcWlmqfzr) {
        return toAjax(tcWlmqfzrService.updateTcWlmqfzr(tcWlmqfzr));
    }

    /**
     * 删除网络民情负责人
     */
    @ApiOperation(value = "删除网络民情负责人")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcWlmqfzrService.deleteTcWlmqfzrByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcWlmqfzr> util = new ExcelUtil<TcWlmqfzr>(TcWlmqfzr.class);
        List<TcWlmqfzr> tcWlmqfzrList = util.importExcel(file.getInputStream());
        tcWlmqfzrService.importUser(tcWlmqfzrList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcWlmqfzrService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcWlmqfzr> util = new ExcelUtil<TcWlmqfzr>(TcWlmqfzr.class);
        util.importTemplateExcel(response, " 网络民情负责人");
    }
}
